/****************************************************************/
/* OPARMS.CMD takes a file name and the parameters associated   */
/* with the file, removed the O in front of the parameters that */
/* come from the UNIXLPR command, then sends the file to the    */
/* queue specified in the command.  The filename, parameters    */
/* and queue are passed in as parameters to the command (it     */
/* doesn't go out and get the parameters given the file name).  */
/*                                                              */
/* To set it up you must do the following:                      */
/*   - Create an intermediate queue invoking this command file. */
/*     See the HELP section below for command format and more   */
/*     details.                                                 */
/*                                                              */
/* The parameters are:                                          */
/*   - Input file name                                          */
/*   - Output queue name (for APRINT command to use)            */
/*   - File parameters (for APRINT command to use)              */
/*                                                              */
/* This command is meant to be used as part of the Transform    */
/* Exit being invoked by XFMFLTR or GENERIC Transform Exits.    */
/****************************************************************/

/* Save local environment to make sure no changes are made. */
x = setlocal()

/* Don't echo commands */
echo = '@'

/* Read in the parameters from the command line */
ARG commandline

/* Check command line parameters, and assign to variables */
if WORDS(commandline) <> 0 then do
  if WORDS(commandline) >= 3 then do
    inputdat = WORD(commandline, 1)
    queuename = WORD(commandline, 2)
    tempindx = WORDINDEX(commandline, 3)
    if (tempindx <> 0) then do
      parmsdat = SUBSTR(commandline, tempindx)
    end
    else do
      parmsdat = ''
    end
  end
  else do
    CALL HELP;
  end
end
else do
  CALL HELP;
end

/* Write parameters to output file for debugging */
/* outputdat = 'c:\oparms.txt'
tempout = 'inputdat = 'inputdat
retcode = LINEOUT(outputdat, tempout);
tempout = 'queuename = 'queuename
retcode = LINEOUT(outputdat, tempout);
tempout = 'parmsdat = "'parmsdat'"'
retcode = LINEOUT(outputdat, tempout);
retcode = LINEOUT(outputdat) */

/* initialize variables */
parmsdat2 = ''
parmwords = WORDS(parmsdat)

/* Check all parameters for an 'O' in the first position.  If it has */
/* an 'O' in the first position, remove it leaving the rest alone.   */
/* There are no APRINT parameters with an 'O' in the first position, */
/* so this should work for all valid parameters.                     */
if (parmwords <> 0) then do
  do index = 1 TO parmwords
    curparm = WORD(parmsdat, index)
    firstchar = SUBSTR(curparm, 1, 1)
    if (firstchar = 'O') | (firstchar = 'o') then do
      curparm = SUBSTR(curparm, 2)
    end
    parmsdat2 = parmsdat2 || curparm || ' '
  end
end

/* Write parameters to output file for debugging */
/* tempout = 'parmsdat2 = "'parmsdat2'"'
retcode = LINEOUT(outputdat, tempout);
tempout = 'APRINT 'inputdat' D='queuename' 'parmsdat2
retcode = LINEOUT(outputdat, tempout);
retcode = LINEOUT(outputdat) */

/* Transfer output file to PSF/2 queue with parameters */
'APRINT 'inputdat' D='queuename' 'parmsdat2

x = endlocal()
CALL QUIT;

HELP:;
  say '**************************************************************';
  say '* This command can be used to allow usage of APRINT commands *';
  say '* from UNIX via the UNIXLPR command.  The parameters passed  *';
  say '* with the file will be passed to the PSF/2 queue via an     *';
  say '* APRINT command after the UNIXLPR characters have been      *';
  say '* stripped off.  To invoke this CMD file, use the PSF/2      *';
  say '* Transform Exit layer via the XFMFLTR.DLL or GENERIC.DLL    *';
  say '* transform.                                                 *';
  say '*                                                            *';
  say '* This command REQUIRES two parameters, with remaining       *';
  say '* parameters being the ones used to submit the job with      *';
  say '* the APRINT command.                                        *';
  say '*                                                            *';
  say '* The format is:                                             *';
  say '*   OPARMS <input source> <queue name> <parameters>          *';
  say '*                                                            *';
  say '* where:                                                     *';
  say '*   <input source> is the fully qualified name of a file     *';
  say '*     with the data from Netware in it. %i is usually used.  *';
  say '*   <queue name> is the name of the PSF/2 queue for the      *';
  say '*     APRINT command DEST parameter.                         *';
  say '*   <parameters> are the parameters to be submitted to PSF/2 *';
  say '*     using the APRINT command.  This can be blank.          *';
  say '*                                                            *';
  say '* Example line to put in XFMFLTR or GENERIC transform:       *';
  say '*   c:\psf2\unixlpr\oparms.cmd %i PSF4019Q %a                *';
  say '*                                                            *';
  say '**************************************************************';
  x = endlocal()
  CALL QUIT;
RETURN;

QUIT:;
EXIT;
